@@ -1,7 +1,7 @@
 package Config::IOD::Base;
 
-our $DATE = '2015-03-13'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2015-03-18'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -20,6 +20,7 @@ sub new {
     my ($class, %attrs) = @_;
     $attrs{default_section} //= 'GLOBAL';
     $attrs{allow_bang_only} //= 1;
+    $attrs{allow_duplicate_key} //= 1;
     $attrs{enable_encoding} //= 1;
     $attrs{enable_quoting}  //= 1;
     $attrs{enable_bracket}  //= 1;
@@ -425,7 +426,7 @@ Config::IOD::Base - Base class for Config::IOD and Config::IOD::Reader
 
 =head1 VERSION
 
-This document describes version 0.09 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2015-03-13.
+This document describes version 0.10 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2015-03-18.
 
 =head1 ATTRIBUTES
 
@@ -519,6 +520,30 @@ instead of the correct:
 is very common, the spec allows it. This reader, however, can be configured to
 be more strict.
 
+=head2 allow_duplicate_key => bool (default: 1)
+
+If set to 0, you can forbid duplicate key, e.g.:
+
+ [section]
+ a=1
+ a=2
+
+or:
+
+ [section]
+ a=1
+ b=2
+ c=3
+ a=10
+
+In traditional INI file, to specify an array you specify multiple keys. But when
+there is only a single key, it is unclear if the value is a single-element array
+or a scalar. You can use this setting to avoid this array/scalar ambiguity in
+config file and force user to use JSON encoding or bracket to specify array:
+
+ [section]
+ a=[1,2]
+
 =for END_BLOCK: attributes
 
 =head1 EXPRESSION
