@@ -1,7 +1,7 @@
 package Config::IOD::Reader;
 
-our $DATE = '2015-03-13'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2015-03-18'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -130,8 +130,8 @@ sub _read_string {
 
         # key line
         if ($line =~ /^\s*([^=]+?)\s*=\s*(.*)/) {
-            my $name = $1;
-            my $val  = $2;
+            my $key = $1;
+            my $val = $2;
 
             # the common case is that value are not decoded or
             # quoted/bracketed/braced, so we avoid calling _parse_raw_value here
@@ -144,15 +144,17 @@ sub _read_string {
                 $val =~ s/\s*[#;].*//; # strip comment
             }
 
-            if (exists $res->{$cur_section}{$name}) {
-                if ($self->{_arrayified}{$cur_section}{$name}++) {
-                    push @{ $res->{$cur_section}{$name} }, $val;
+            if (exists $res->{$cur_section}{$key}) {
+                if (!$self->{allow_duplicate_key}) {
+                    $self->_err("Duplicate key: $key (section $cur_section)");
+                } elsif ($self->{_arrayified}{$cur_section}{$key}++) {
+                    push @{ $res->{$cur_section}{$key} }, $val;
                 } else {
-                    $res->{$cur_section}{$name} = [
-                        $res->{$cur_section}{$name}, $val];
+                    $res->{$cur_section}{$key} = [
+                        $res->{$cur_section}{$key}, $val];
                 }
             } else {
-                $res->{$cur_section}{$name} = $val;
+                $res->{$cur_section}{$key} = $val;
             }
 
             next LINE;
@@ -183,7 +185,7 @@ Config::IOD::Reader - Read IOD configuration files
 
 =head1 VERSION
 
-This document describes version 0.09 of Config::IOD::Reader (from Perl distribution Config-IOD-Reader), released on 2015-03-13.
+This document describes version 0.10 of Config::IOD::Reader (from Perl distribution Config-IOD-Reader), released on 2015-03-18.
 
 =head1 SYNOPSIS
 
@@ -350,6 +352,30 @@ instead of the correct:
 is very common, the spec allows it. This reader, however, can be configured to
 be more strict.
 
+=head2 allow_duplicate_key => bool (default: 1)
+
+If set to 0, you can forbid duplicate key, e.g.:
+
+ [section]
+ a=1
+ a=2
+
+or:
+
+ [section]
+ a=1
+ b=2
+ c=3
+ a=10
+
+In traditional INI file, to specify an array you specify multiple keys. But when
+there is only a single key, it is unclear if the value is a single-element array
+or a scalar. You can use this setting to avoid this array/scalar ambiguity in
+config file and force user to use JSON encoding or bracket to specify array:
+
+ [section]
+ a=[1,2]
+
 =head1 METHODS
 
 =head2 new(%attrs) => obj
